@@ -3,11 +3,12 @@
     ani.options(withprompt = c(options(prompt = ani.options("withprompt"))$prompt,
         ani.options("withprompt")))
     ani.options(outdir = c(ani.options("outdir"), setwd(ani.options("outdir"))))
-    if (!file.exists("images")) {
-        dir.create("images")
+    imgdir = ani.options("imgdir")
+    if (!file.exists(imgdir)) {
+        dir.create(imgdir)
     }
     else {
-        file.remove(list.files("images", full.names = TRUE))
+        file.remove(list.files(imgdir, full.names = TRUE))
     }
     file.copy(system.file("js", "ANI.css", package = "animation"),
         "ANI.css", overwrite = TRUE)
@@ -15,6 +16,7 @@
         "FUN.js", overwrite = TRUE)
     ani.options(interval = c(0, ani.options("interval")))
     dev = ani.options("ani.dev")
-    dev(filename = paste("images/%d", ".", ani.options("ani.type"), sep = ""),
+    if (is.character(dev)) dev = get(dev)
+    dev(filename = paste(imgdir, "/%d", ".", ani.options("ani.type"), sep = ""),
         width = ani.options("ani.width"), height = ani.options("ani.height"))
 }
